PyDiagram Changelog
===================

Version 0.4
-----------

* Provide predictor mode in pydiagram executable

Version 0.3
-----------

* Provide an executable for general usage.
* Support parsing PolyFTS results.
* Support project configuration file.
* Fix many bugs.
* Fix most of PEP8 violations.

Version 0.2
-----------

* Add I/O interface for loading and dumping .dgm files.
* Add .dgm file format to communicate with other software packages.

Version 0.1
-----------

* First release.

Initiated
---------

* Mar. 16th, 2015
